from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage.Streams
import win32more.Windows.System
import win32more.Windows.System.Profile
import win32more.Windows.Win32.System.WinRT
class _AnalyticsInfo_Meta_(ComPtr.__class__):
    pass
class AnalyticsInfo(ComPtr, metaclass=_AnalyticsInfo_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.AnalyticsInfo'
    @winrt_classmethod
    def GetSystemPropertiesAsync(cls: win32more.Windows.System.Profile.IAnalyticsInfoStatics2, attributeNames: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]]: ...
    @winrt_classmethod
    def get_VersionInfo(cls: win32more.Windows.System.Profile.IAnalyticsInfoStatics) -> win32more.Windows.System.Profile.AnalyticsVersionInfo: ...
    @winrt_classmethod
    def get_DeviceForm(cls: win32more.Windows.System.Profile.IAnalyticsInfoStatics) -> WinRT_String: ...
    _AnalyticsInfo_Meta_.DeviceForm = property(get_DeviceForm, None)
    _AnalyticsInfo_Meta_.VersionInfo = property(get_VersionInfo, None)
class AnalyticsVersionInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Profile.IAnalyticsVersionInfo
    _classid_ = 'Windows.System.Profile.AnalyticsVersionInfo'
    @winrt_mixinmethod
    def get_DeviceFamily(self: win32more.Windows.System.Profile.IAnalyticsVersionInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_DeviceFamilyVersion(self: win32more.Windows.System.Profile.IAnalyticsVersionInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ProductName(self: win32more.Windows.System.Profile.IAnalyticsVersionInfo2) -> WinRT_String: ...
    DeviceFamily = property(get_DeviceFamily, None)
    DeviceFamilyVersion = property(get_DeviceFamilyVersion, None)
    ProductName = property(get_ProductName, None)
class AppApplicability(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.AppApplicability'
    @winrt_classmethod
    def GetUnsupportedAppRequirements(cls: win32more.Windows.System.Profile.IAppApplicabilityStatics, capabilities: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.System.Profile.UnsupportedAppRequirement]: ...
class _EducationSettings_Meta_(ComPtr.__class__):
    pass
class EducationSettings(ComPtr, metaclass=_EducationSettings_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.EducationSettings'
    @winrt_classmethod
    def get_IsEducationEnvironment(cls: win32more.Windows.System.Profile.IEducationSettingsStatics) -> Boolean: ...
    _EducationSettings_Meta_.IsEducationEnvironment = property(get_IsEducationEnvironment, None)
class HardwareIdentification(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.HardwareIdentification'
    @winrt_classmethod
    def GetPackageSpecificToken(cls: win32more.Windows.System.Profile.IHardwareIdentificationStatics, nonce: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.System.Profile.HardwareToken: ...
class HardwareToken(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Profile.IHardwareToken
    _classid_ = 'Windows.System.Profile.HardwareToken'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.System.Profile.IHardwareToken) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_mixinmethod
    def get_Signature(self: win32more.Windows.System.Profile.IHardwareToken) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_mixinmethod
    def get_Certificate(self: win32more.Windows.System.Profile.IHardwareToken) -> win32more.Windows.Storage.Streams.IBuffer: ...
    Certificate = property(get_Certificate, None)
    Id = property(get_Id, None)
    Signature = property(get_Signature, None)
class IAnalyticsInfoStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.IAnalyticsInfoStatics'
    _iid_ = Guid('{1d5ee066-188d-5ba9-4387-acaeb0e7e305}')
    @winrt_commethod(6)
    def get_VersionInfo(self) -> win32more.Windows.System.Profile.AnalyticsVersionInfo: ...
    @winrt_commethod(7)
    def get_DeviceForm(self) -> WinRT_String: ...
    DeviceForm = property(get_DeviceForm, None)
    VersionInfo = property(get_VersionInfo, None)
class IAnalyticsInfoStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.IAnalyticsInfoStatics2'
    _iid_ = Guid('{101704ea-a7f9-46d2-ab94-016865afdb25}')
    @winrt_commethod(6)
    def GetSystemPropertiesAsync(self, attributeNames: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]]: ...
class IAnalyticsVersionInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.IAnalyticsVersionInfo'
    _iid_ = Guid('{926130b8-9955-4c74-bdc1-7cd0decf9b03}')
    @winrt_commethod(6)
    def get_DeviceFamily(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_DeviceFamilyVersion(self) -> WinRT_String: ...
    DeviceFamily = property(get_DeviceFamily, None)
    DeviceFamilyVersion = property(get_DeviceFamilyVersion, None)
class IAnalyticsVersionInfo2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.IAnalyticsVersionInfo2'
    _iid_ = Guid('{76e915b1-ff36-407c-9f57-160d3e540747}')
    @winrt_commethod(6)
    def get_ProductName(self) -> WinRT_String: ...
    ProductName = property(get_ProductName, None)
class IAppApplicabilityStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.IAppApplicabilityStatics'
    _iid_ = Guid('{1664a082-0f38-5c99-83e4-48995970861c}')
    @winrt_commethod(6)
    def GetUnsupportedAppRequirements(self, capabilities: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.System.Profile.UnsupportedAppRequirement]: ...
class IEducationSettingsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.IEducationSettingsStatics'
    _iid_ = Guid('{fc53f0ef-4d3e-4e13-9b23-505f4d091e92}')
    @winrt_commethod(6)
    def get_IsEducationEnvironment(self) -> Boolean: ...
    IsEducationEnvironment = property(get_IsEducationEnvironment, None)
class IHardwareIdentificationStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.IHardwareIdentificationStatics'
    _iid_ = Guid('{971260e0-f170-4a42-bd55-a900b212dae2}')
    @winrt_commethod(6)
    def GetPackageSpecificToken(self, nonce: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.System.Profile.HardwareToken: ...
class IHardwareToken(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.IHardwareToken'
    _iid_ = Guid('{28f6d4c0-fb12-40a4-8167-7f4e03d2724c}')
    @winrt_commethod(6)
    def get_Id(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_commethod(7)
    def get_Signature(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_commethod(8)
    def get_Certificate(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    Certificate = property(get_Certificate, None)
    Id = property(get_Id, None)
    Signature = property(get_Signature, None)
class IKnownRetailInfoPropertiesStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.IKnownRetailInfoPropertiesStatics'
    _iid_ = Guid('{99571178-500f-487e-8e75-29e551728712}')
    @winrt_commethod(6)
    def get_RetailAccessCode(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_ManufacturerName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_ModelName(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_DisplayModelName(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_Price(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def get_IsFeatured(self) -> WinRT_String: ...
    @winrt_commethod(12)
    def get_FormFactor(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def get_ScreenSize(self) -> WinRT_String: ...
    @winrt_commethod(14)
    def get_Weight(self) -> WinRT_String: ...
    @winrt_commethod(15)
    def get_DisplayDescription(self) -> WinRT_String: ...
    @winrt_commethod(16)
    def get_BatteryLifeDescription(self) -> WinRT_String: ...
    @winrt_commethod(17)
    def get_ProcessorDescription(self) -> WinRT_String: ...
    @winrt_commethod(18)
    def get_Memory(self) -> WinRT_String: ...
    @winrt_commethod(19)
    def get_StorageDescription(self) -> WinRT_String: ...
    @winrt_commethod(20)
    def get_GraphicsDescription(self) -> WinRT_String: ...
    @winrt_commethod(21)
    def get_FrontCameraDescription(self) -> WinRT_String: ...
    @winrt_commethod(22)
    def get_RearCameraDescription(self) -> WinRT_String: ...
    @winrt_commethod(23)
    def get_HasNfc(self) -> WinRT_String: ...
    @winrt_commethod(24)
    def get_HasSdSlot(self) -> WinRT_String: ...
    @winrt_commethod(25)
    def get_HasOpticalDrive(self) -> WinRT_String: ...
    @winrt_commethod(26)
    def get_IsOfficeInstalled(self) -> WinRT_String: ...
    @winrt_commethod(27)
    def get_WindowsEdition(self) -> WinRT_String: ...
    BatteryLifeDescription = property(get_BatteryLifeDescription, None)
    DisplayDescription = property(get_DisplayDescription, None)
    DisplayModelName = property(get_DisplayModelName, None)
    FormFactor = property(get_FormFactor, None)
    FrontCameraDescription = property(get_FrontCameraDescription, None)
    GraphicsDescription = property(get_GraphicsDescription, None)
    HasNfc = property(get_HasNfc, None)
    HasOpticalDrive = property(get_HasOpticalDrive, None)
    HasSdSlot = property(get_HasSdSlot, None)
    IsFeatured = property(get_IsFeatured, None)
    IsOfficeInstalled = property(get_IsOfficeInstalled, None)
    ManufacturerName = property(get_ManufacturerName, None)
    Memory = property(get_Memory, None)
    ModelName = property(get_ModelName, None)
    Price = property(get_Price, None)
    ProcessorDescription = property(get_ProcessorDescription, None)
    RearCameraDescription = property(get_RearCameraDescription, None)
    RetailAccessCode = property(get_RetailAccessCode, None)
    ScreenSize = property(get_ScreenSize, None)
    StorageDescription = property(get_StorageDescription, None)
    Weight = property(get_Weight, None)
    WindowsEdition = property(get_WindowsEdition, None)
class IPlatformAutomaticAppSignInManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.IPlatformAutomaticAppSignInManagerStatics'
    _iid_ = Guid('{1ac9afce-8dd5-5c2d-b420-767d1f3b7d03}')
    @winrt_commethod(6)
    def get_Policy(self) -> win32more.Windows.System.Profile.PlatformAutomaticAppSignInPolicy: ...
    Policy = property(get_Policy, None)
class IPlatformDiagnosticsAndUsageDataSettingsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.IPlatformDiagnosticsAndUsageDataSettingsStatics'
    _iid_ = Guid('{b6e24c1b-7b1c-4b32-8c62-a66597ce723a}')
    @winrt_commethod(6)
    def get_CollectionLevel(self) -> win32more.Windows.System.Profile.PlatformDataCollectionLevel: ...
    @winrt_commethod(7)
    def add_CollectionLevelChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_CollectionLevelChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(9)
    def CanCollectDiagnostics(self, level: win32more.Windows.System.Profile.PlatformDataCollectionLevel) -> Boolean: ...
    CollectionLevel = property(get_CollectionLevel, None)
    CollectionLevelChanged = event()
class IRetailInfoStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.IRetailInfoStatics'
    _iid_ = Guid('{0712c6b8-8b92-4f2a-8499-031f1798d6ef}')
    @winrt_commethod(6)
    def get_IsDemoModeEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_Properties(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    IsDemoModeEnabled = property(get_IsDemoModeEnabled, None)
    Properties = property(get_Properties, None)
class ISharedModeSettingsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.ISharedModeSettingsStatics'
    _iid_ = Guid('{893df40e-cad6-4d50-8c49-6fcfc03edb29}')
    @winrt_commethod(6)
    def get_IsEnabled(self) -> Boolean: ...
    IsEnabled = property(get_IsEnabled, None)
class ISharedModeSettingsStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.ISharedModeSettingsStatics2'
    _iid_ = Guid('{608988a4-ccf1-4ee8-a5e2-fd6a1d0cfac8}')
    @winrt_commethod(6)
    def get_ShouldAvoidLocalStorage(self) -> Boolean: ...
    ShouldAvoidLocalStorage = property(get_ShouldAvoidLocalStorage, None)
class ISmartAppControlPolicyStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.ISmartAppControlPolicyStatics'
    _iid_ = Guid('{5ff8c75b-073e-5015-8d98-5ff224180a0b}')
    @winrt_commethod(6)
    def get_IsEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def add_Changed(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_Changed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    IsEnabled = property(get_IsEnabled, None)
    Changed = event()
class ISystemIdentificationInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.ISystemIdentificationInfo'
    _iid_ = Guid('{0c659e7d-c3c2-4d33-a2df-21bc41916eb3}')
    @winrt_commethod(6)
    def get_Id(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_commethod(7)
    def get_Source(self) -> win32more.Windows.System.Profile.SystemIdentificationSource: ...
    Id = property(get_Id, None)
    Source = property(get_Source, None)
class ISystemIdentificationStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.ISystemIdentificationStatics'
    _iid_ = Guid('{5581f42a-d3df-4d93-a37d-c41a616c6d01}')
    @winrt_commethod(6)
    def GetSystemIdForPublisher(self) -> win32more.Windows.System.Profile.SystemIdentificationInfo: ...
    @winrt_commethod(7)
    def GetSystemIdForUser(self, user: win32more.Windows.System.User) -> win32more.Windows.System.Profile.SystemIdentificationInfo: ...
class ISystemSetupInfoStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.ISystemSetupInfoStatics'
    _iid_ = Guid('{b8366a4b-fb6a-4571-be0a-9a0f67954123}')
    @winrt_commethod(6)
    def get_OutOfBoxExperienceState(self) -> win32more.Windows.System.Profile.SystemOutOfBoxExperienceState: ...
    @winrt_commethod(7)
    def add_OutOfBoxExperienceStateChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_OutOfBoxExperienceStateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    OutOfBoxExperienceState = property(get_OutOfBoxExperienceState, None)
    OutOfBoxExperienceStateChanged = event()
class IUnsupportedAppRequirement(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.IUnsupportedAppRequirement'
    _iid_ = Guid('{6182445c-894b-5cbc-8976-a98e0a9b998d}')
    @winrt_commethod(6)
    def get_Requirement(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Reasons(self) -> win32more.Windows.System.Profile.UnsupportedAppRequirementReasons: ...
    Reasons = property(get_Reasons, None)
    Requirement = property(get_Requirement, None)
class IWindowsIntegrityPolicyStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.IWindowsIntegrityPolicyStatics'
    _iid_ = Guid('{7d1d81db-8d63-4789-9ea5-ddcf65a94f3c}')
    @winrt_commethod(6)
    def get_IsEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_IsEnabledForTrial(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_CanDisable(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_IsDisableSupported(self) -> Boolean: ...
    @winrt_commethod(10)
    def add_PolicyChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_PolicyChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CanDisable = property(get_CanDisable, None)
    IsDisableSupported = property(get_IsDisableSupported, None)
    IsEnabled = property(get_IsEnabled, None)
    IsEnabledForTrial = property(get_IsEnabledForTrial, None)
    PolicyChanged = event()
class _KnownRetailInfoProperties_Meta_(ComPtr.__class__):
    pass
class KnownRetailInfoProperties(ComPtr, metaclass=_KnownRetailInfoProperties_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.KnownRetailInfoProperties'
    @winrt_classmethod
    def get_RetailAccessCode(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_ManufacturerName(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_ModelName(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_DisplayModelName(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_Price(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_IsFeatured(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_FormFactor(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_ScreenSize(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_Weight(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_DisplayDescription(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_BatteryLifeDescription(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_ProcessorDescription(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_Memory(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_StorageDescription(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_GraphicsDescription(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_FrontCameraDescription(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_RearCameraDescription(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_HasNfc(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_HasSdSlot(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_HasOpticalDrive(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_IsOfficeInstalled(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_WindowsEdition(cls: win32more.Windows.System.Profile.IKnownRetailInfoPropertiesStatics) -> WinRT_String: ...
    _KnownRetailInfoProperties_Meta_.BatteryLifeDescription = property(get_BatteryLifeDescription, None)
    _KnownRetailInfoProperties_Meta_.DisplayDescription = property(get_DisplayDescription, None)
    _KnownRetailInfoProperties_Meta_.DisplayModelName = property(get_DisplayModelName, None)
    _KnownRetailInfoProperties_Meta_.FormFactor = property(get_FormFactor, None)
    _KnownRetailInfoProperties_Meta_.FrontCameraDescription = property(get_FrontCameraDescription, None)
    _KnownRetailInfoProperties_Meta_.GraphicsDescription = property(get_GraphicsDescription, None)
    _KnownRetailInfoProperties_Meta_.HasNfc = property(get_HasNfc, None)
    _KnownRetailInfoProperties_Meta_.HasOpticalDrive = property(get_HasOpticalDrive, None)
    _KnownRetailInfoProperties_Meta_.HasSdSlot = property(get_HasSdSlot, None)
    _KnownRetailInfoProperties_Meta_.IsFeatured = property(get_IsFeatured, None)
    _KnownRetailInfoProperties_Meta_.IsOfficeInstalled = property(get_IsOfficeInstalled, None)
    _KnownRetailInfoProperties_Meta_.ManufacturerName = property(get_ManufacturerName, None)
    _KnownRetailInfoProperties_Meta_.Memory = property(get_Memory, None)
    _KnownRetailInfoProperties_Meta_.ModelName = property(get_ModelName, None)
    _KnownRetailInfoProperties_Meta_.Price = property(get_Price, None)
    _KnownRetailInfoProperties_Meta_.ProcessorDescription = property(get_ProcessorDescription, None)
    _KnownRetailInfoProperties_Meta_.RearCameraDescription = property(get_RearCameraDescription, None)
    _KnownRetailInfoProperties_Meta_.RetailAccessCode = property(get_RetailAccessCode, None)
    _KnownRetailInfoProperties_Meta_.ScreenSize = property(get_ScreenSize, None)
    _KnownRetailInfoProperties_Meta_.StorageDescription = property(get_StorageDescription, None)
    _KnownRetailInfoProperties_Meta_.Weight = property(get_Weight, None)
    _KnownRetailInfoProperties_Meta_.WindowsEdition = property(get_WindowsEdition, None)
PlatformAutomaticAppSignInContract: UInt32 = 65536
class _PlatformAutomaticAppSignInManager_Meta_(ComPtr.__class__):
    pass
class PlatformAutomaticAppSignInManager(ComPtr, metaclass=_PlatformAutomaticAppSignInManager_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.PlatformAutomaticAppSignInManager'
    @winrt_classmethod
    def get_Policy(cls: win32more.Windows.System.Profile.IPlatformAutomaticAppSignInManagerStatics) -> win32more.Windows.System.Profile.PlatformAutomaticAppSignInPolicy: ...
    _PlatformAutomaticAppSignInManager_Meta_.Policy = property(get_Policy, None)
class PlatformAutomaticAppSignInPolicy(Enum, Int32):
    Unknown = 0
    PermissionRequired = 1
    AlwaysAllowed = 2
class PlatformDataCollectionLevel(Enum, Int32):
    Security = 0
    Basic = 1
    Enhanced = 2
    Full = 3
class _PlatformDiagnosticsAndUsageDataSettings_Meta_(ComPtr.__class__):
    pass
class PlatformDiagnosticsAndUsageDataSettings(ComPtr, metaclass=_PlatformDiagnosticsAndUsageDataSettings_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.PlatformDiagnosticsAndUsageDataSettings'
    @winrt_classmethod
    def get_CollectionLevel(cls: win32more.Windows.System.Profile.IPlatformDiagnosticsAndUsageDataSettingsStatics) -> win32more.Windows.System.Profile.PlatformDataCollectionLevel: ...
    @winrt_classmethod
    def add_CollectionLevelChanged(cls: win32more.Windows.System.Profile.IPlatformDiagnosticsAndUsageDataSettingsStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_CollectionLevelChanged(cls: win32more.Windows.System.Profile.IPlatformDiagnosticsAndUsageDataSettingsStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def CanCollectDiagnostics(cls: win32more.Windows.System.Profile.IPlatformDiagnosticsAndUsageDataSettingsStatics, level: win32more.Windows.System.Profile.PlatformDataCollectionLevel) -> Boolean: ...
    _PlatformDiagnosticsAndUsageDataSettings_Meta_.CollectionLevel = property(get_CollectionLevel, None)
ProfileHardwareTokenContract: UInt32 = 65536
ProfileRetailInfoContract: UInt32 = 65536
ProfileSharedModeContract: UInt32 = 131072
class _RetailInfo_Meta_(ComPtr.__class__):
    pass
class RetailInfo(ComPtr, metaclass=_RetailInfo_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.RetailInfo'
    @winrt_classmethod
    def get_IsDemoModeEnabled(cls: win32more.Windows.System.Profile.IRetailInfoStatics) -> Boolean: ...
    @winrt_classmethod
    def get_Properties(cls: win32more.Windows.System.Profile.IRetailInfoStatics) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    _RetailInfo_Meta_.IsDemoModeEnabled = property(get_IsDemoModeEnabled, None)
    _RetailInfo_Meta_.Properties = property(get_Properties, None)
class _SharedModeSettings_Meta_(ComPtr.__class__):
    pass
class SharedModeSettings(ComPtr, metaclass=_SharedModeSettings_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.SharedModeSettings'
    @winrt_classmethod
    def get_ShouldAvoidLocalStorage(cls: win32more.Windows.System.Profile.ISharedModeSettingsStatics2) -> Boolean: ...
    @winrt_classmethod
    def get_IsEnabled(cls: win32more.Windows.System.Profile.ISharedModeSettingsStatics) -> Boolean: ...
    _SharedModeSettings_Meta_.IsEnabled = property(get_IsEnabled, None)
    _SharedModeSettings_Meta_.ShouldAvoidLocalStorage = property(get_ShouldAvoidLocalStorage, None)
class _SmartAppControlPolicy_Meta_(ComPtr.__class__):
    pass
class SmartAppControlPolicy(ComPtr, metaclass=_SmartAppControlPolicy_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.SmartAppControlPolicy'
    @winrt_classmethod
    def get_IsEnabled(cls: win32more.Windows.System.Profile.ISmartAppControlPolicyStatics) -> Boolean: ...
    @winrt_classmethod
    def add_Changed(cls: win32more.Windows.System.Profile.ISmartAppControlPolicyStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_Changed(cls: win32more.Windows.System.Profile.ISmartAppControlPolicyStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    _SmartAppControlPolicy_Meta_.IsEnabled = property(get_IsEnabled, None)
class SystemIdentification(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.SystemIdentification'
    @winrt_classmethod
    def GetSystemIdForPublisher(cls: win32more.Windows.System.Profile.ISystemIdentificationStatics) -> win32more.Windows.System.Profile.SystemIdentificationInfo: ...
    @winrt_classmethod
    def GetSystemIdForUser(cls: win32more.Windows.System.Profile.ISystemIdentificationStatics, user: win32more.Windows.System.User) -> win32more.Windows.System.Profile.SystemIdentificationInfo: ...
class SystemIdentificationInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Profile.ISystemIdentificationInfo
    _classid_ = 'Windows.System.Profile.SystemIdentificationInfo'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.System.Profile.ISystemIdentificationInfo) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Windows.System.Profile.ISystemIdentificationInfo) -> win32more.Windows.System.Profile.SystemIdentificationSource: ...
    Id = property(get_Id, None)
    Source = property(get_Source, None)
class SystemIdentificationSource(Enum, Int32):
    None_ = 0
    Tpm = 1
    Uefi = 2
    Registry = 3
class SystemOutOfBoxExperienceState(Enum, Int32):
    NotStarted = 0
    InProgress = 1
    Completed = 2
class _SystemSetupInfo_Meta_(ComPtr.__class__):
    pass
class SystemSetupInfo(ComPtr, metaclass=_SystemSetupInfo_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.SystemSetupInfo'
    @winrt_classmethod
    def get_OutOfBoxExperienceState(cls: win32more.Windows.System.Profile.ISystemSetupInfoStatics) -> win32more.Windows.System.Profile.SystemOutOfBoxExperienceState: ...
    @winrt_classmethod
    def add_OutOfBoxExperienceStateChanged(cls: win32more.Windows.System.Profile.ISystemSetupInfoStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_OutOfBoxExperienceStateChanged(cls: win32more.Windows.System.Profile.ISystemSetupInfoStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    _SystemSetupInfo_Meta_.OutOfBoxExperienceState = property(get_OutOfBoxExperienceState, None)
class UnsupportedAppRequirement(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Profile.IUnsupportedAppRequirement
    _classid_ = 'Windows.System.Profile.UnsupportedAppRequirement'
    @winrt_mixinmethod
    def get_Requirement(self: win32more.Windows.System.Profile.IUnsupportedAppRequirement) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Reasons(self: win32more.Windows.System.Profile.IUnsupportedAppRequirement) -> win32more.Windows.System.Profile.UnsupportedAppRequirementReasons: ...
    Reasons = property(get_Reasons, None)
    Requirement = property(get_Requirement, None)
class UnsupportedAppRequirementReasons(Enum, UInt32):
    Unknown = 0
    DeniedBySystem = 1
class _WindowsIntegrityPolicy_Meta_(ComPtr.__class__):
    pass
class WindowsIntegrityPolicy(ComPtr, metaclass=_WindowsIntegrityPolicy_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Profile.WindowsIntegrityPolicy'
    @winrt_classmethod
    def get_IsEnabled(cls: win32more.Windows.System.Profile.IWindowsIntegrityPolicyStatics) -> Boolean: ...
    @winrt_classmethod
    def get_IsEnabledForTrial(cls: win32more.Windows.System.Profile.IWindowsIntegrityPolicyStatics) -> Boolean: ...
    @winrt_classmethod
    def get_CanDisable(cls: win32more.Windows.System.Profile.IWindowsIntegrityPolicyStatics) -> Boolean: ...
    @winrt_classmethod
    def get_IsDisableSupported(cls: win32more.Windows.System.Profile.IWindowsIntegrityPolicyStatics) -> Boolean: ...
    @winrt_classmethod
    def add_PolicyChanged(cls: win32more.Windows.System.Profile.IWindowsIntegrityPolicyStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_PolicyChanged(cls: win32more.Windows.System.Profile.IWindowsIntegrityPolicyStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    _WindowsIntegrityPolicy_Meta_.CanDisable = property(get_CanDisable, None)
    _WindowsIntegrityPolicy_Meta_.IsDisableSupported = property(get_IsDisableSupported, None)
    _WindowsIntegrityPolicy_Meta_.IsEnabled = property(get_IsEnabled, None)
    _WindowsIntegrityPolicy_Meta_.IsEnabledForTrial = property(get_IsEnabledForTrial, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Direct2D.Common
import win32more.Windows.Win32.Graphics.Direct3D
import win32more.Windows.Win32.Graphics.DirectComposition
import win32more.Windows.Win32.Graphics.Dxgi
import win32more.Windows.Win32.Graphics.Dxgi.Common
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.System.Com
COMPOSITIONOBJECT_READ: Int32 = 1
COMPOSITIONOBJECT_WRITE: Int32 = 2
DCOMPOSITION_MAX_WAITFORCOMPOSITORCLOCK_OBJECTS: UInt32 = 32
COMPOSITION_STATS_MAX_TARGETS: UInt32 = 256
@winfunctype('dcomp.dll')
def DCompositionCreateDevice(dxgiDevice: win32more.Windows.Win32.Graphics.Dxgi.IDXGIDevice, iid: POINTER(Guid), dcompositionDevice: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dcomp.dll')
def DCompositionCreateDevice2(renderingDevice: win32more.Windows.Win32.System.Com.IUnknown, iid: POINTER(Guid), dcompositionDevice: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dcomp.dll')
def DCompositionCreateDevice3(renderingDevice: win32more.Windows.Win32.System.Com.IUnknown, iid: POINTER(Guid), dcompositionDevice: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dcomp.dll')
def DCompositionCreateSurfaceHandle(desiredAccess: UInt32, securityAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), surfaceHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dcomp.dll')
def DCompositionAttachMouseWheelToHwnd(visual: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionVisual, hwnd: win32more.Windows.Win32.Foundation.HWND, enable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dcomp.dll')
def DCompositionAttachMouseDragToHwnd(visual: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionVisual, hwnd: win32more.Windows.Win32.Foundation.HWND, enable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dcomp.dll')
def DCompositionGetFrameId(frameIdType: win32more.Windows.Win32.Graphics.DirectComposition.COMPOSITION_FRAME_ID_TYPE, frameId: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dcomp.dll')
def DCompositionGetStatistics(frameId: UInt64, frameStats: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.COMPOSITION_FRAME_STATS), targetIdCount: UInt32, targetIds: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.COMPOSITION_TARGET_ID), actualTargetIdCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dcomp.dll')
def DCompositionGetTargetStatistics(frameId: UInt64, targetId: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.COMPOSITION_TARGET_ID), targetStats: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.COMPOSITION_TARGET_STATS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dcomp.dll')
def DCompositionBoostCompositorClock(enable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dcomp.dll')
def DCompositionWaitForCompositorClock(count: UInt32, handles: POINTER(win32more.Windows.Win32.Foundation.HANDLE), timeoutInMs: UInt32) -> UInt32: ...
COMPOSITION_FRAME_ID_TYPE = Int32
COMPOSITION_FRAME_ID_CREATED: win32more.Windows.Win32.Graphics.DirectComposition.COMPOSITION_FRAME_ID_TYPE = 0
COMPOSITION_FRAME_ID_CONFIRMED: win32more.Windows.Win32.Graphics.DirectComposition.COMPOSITION_FRAME_ID_TYPE = 1
COMPOSITION_FRAME_ID_COMPLETED: win32more.Windows.Win32.Graphics.DirectComposition.COMPOSITION_FRAME_ID_TYPE = 2
class COMPOSITION_FRAME_STATS(Structure):
    startTime: UInt64
    targetTime: UInt64
    framePeriod: UInt64
class COMPOSITION_STATS(Structure):
    presentCount: UInt32
    refreshCount: UInt32
    virtualRefreshCount: UInt32
    time: UInt64
class COMPOSITION_TARGET_ID(Structure):
    displayAdapterLuid: win32more.Windows.Win32.Foundation.LUID
    renderAdapterLuid: win32more.Windows.Win32.Foundation.LUID
    vidPnSourceId: UInt32
    vidPnTargetId: UInt32
    uniqueId: UInt32
class COMPOSITION_TARGET_STATS(Structure):
    outstandingPresents: UInt32
    presentTime: UInt64
    vblankDuration: UInt64
    presentedStats: win32more.Windows.Win32.Graphics.DirectComposition.COMPOSITION_STATS
    completedStats: win32more.Windows.Win32.Graphics.DirectComposition.COMPOSITION_STATS
DCOMPOSITION_BACKFACE_VISIBILITY = Int32
DCOMPOSITION_BACKFACE_VISIBILITY_VISIBLE: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_BACKFACE_VISIBILITY = 0
DCOMPOSITION_BACKFACE_VISIBILITY_HIDDEN: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_BACKFACE_VISIBILITY = 1
DCOMPOSITION_BACKFACE_VISIBILITY_INHERIT: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_BACKFACE_VISIBILITY = -1
DCOMPOSITION_BITMAP_INTERPOLATION_MODE = Int32
DCOMPOSITION_BITMAP_INTERPOLATION_MODE_NEAREST_NEIGHBOR: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_BITMAP_INTERPOLATION_MODE = 0
DCOMPOSITION_BITMAP_INTERPOLATION_MODE_LINEAR: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_BITMAP_INTERPOLATION_MODE = 1
DCOMPOSITION_BITMAP_INTERPOLATION_MODE_INHERIT: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_BITMAP_INTERPOLATION_MODE = -1
DCOMPOSITION_BORDER_MODE = Int32
DCOMPOSITION_BORDER_MODE_SOFT: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_BORDER_MODE = 0
DCOMPOSITION_BORDER_MODE_HARD: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_BORDER_MODE = 1
DCOMPOSITION_BORDER_MODE_INHERIT: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_BORDER_MODE = -1
DCOMPOSITION_COMPOSITE_MODE = Int32
DCOMPOSITION_COMPOSITE_MODE_SOURCE_OVER: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_COMPOSITE_MODE = 0
DCOMPOSITION_COMPOSITE_MODE_DESTINATION_INVERT: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_COMPOSITE_MODE = 1
DCOMPOSITION_COMPOSITE_MODE_MIN_BLEND: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_COMPOSITE_MODE = 2
DCOMPOSITION_COMPOSITE_MODE_INHERIT: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_COMPOSITE_MODE = -1
DCOMPOSITION_DEPTH_MODE = Int32
DCOMPOSITION_DEPTH_MODE_TREE: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_DEPTH_MODE = 0
DCOMPOSITION_DEPTH_MODE_SPATIAL: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_DEPTH_MODE = 1
DCOMPOSITION_DEPTH_MODE_SORTED: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_DEPTH_MODE = 3
DCOMPOSITION_DEPTH_MODE_INHERIT: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_DEPTH_MODE = -1
class DCOMPOSITION_FRAME_STATISTICS(Structure):
    lastFrameTime: Int64
    currentCompositionRate: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_RATIONAL
    currentTime: Int64
    timeFrequency: Int64
    nextEstimatedFrameTime: Int64
DCOMPOSITION_OPACITY_MODE = Int32
DCOMPOSITION_OPACITY_MODE_LAYER: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_OPACITY_MODE = 0
DCOMPOSITION_OPACITY_MODE_MULTIPLY: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_OPACITY_MODE = 1
DCOMPOSITION_OPACITY_MODE_INHERIT: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_OPACITY_MODE = -1
class DCompositionInkTrailPoint(Structure):
    x: Single
    y: Single
    radius: Single
class IDCompositionAffineTransform2DEffect(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionFilterEffect
    _iid_ = Guid('{0b74b9e8-cdd6-492f-bbbc-5ed32157026d}')
    @commethod(4)
    def SetInterpolationMode(self, interpolationMode: win32more.Windows.Win32.Graphics.Direct2D.Common.D2D1_2DAFFINETRANSFORM_INTERPOLATION_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetBorderMode(self, borderMode: win32more.Windows.Win32.Graphics.Direct2D.Common.D2D1_BORDER_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetTransformMatrix(self, transformMatrix: POINTER(win32more.Windows.Win32.Graphics.Direct2D.Common.D2D_MATRIX_3X2_F)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetTransformMatrixElement(self, row: Int32, column: Int32, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetTransformMatrixElement(self, row: Int32, column: Int32, value: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetSharpness(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetSharpness(self, sharpness: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionAnimation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cbfd91d9-51b2-45e4-b3de-d19ccfb863c5}')
    @commethod(3)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetAbsoluteBeginTime(self, beginTime: Int64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def AddCubic(self, beginOffset: Double, constantCoefficient: Single, linearCoefficient: Single, quadraticCoefficient: Single, cubicCoefficient: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def AddSinusoidal(self, beginOffset: Double, bias: Single, amplitude: Single, frequency: Single, phase: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def AddRepeat(self, beginOffset: Double, durationToRepeat: Double) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def End(self, endOffset: Double, endValue: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionArithmeticCompositeEffect(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionFilterEffect
    _iid_ = Guid('{3b67dfa8-e3dd-4e61-b640-46c2f3d739dc}')
    @commethod(4)
    def SetCoefficients(self, coefficients: POINTER(win32more.Windows.Win32.Graphics.Direct2D.Common.D2D_VECTOR_4F)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetClampOutput(self, clampoutput: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetCoefficient1(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetCoefficient1(self, Coeffcient1: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetCoefficient2(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetCoefficient2(self, Coefficient2: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetCoefficient3(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetCoefficient3(self, Coefficient3: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetCoefficient4(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetCoefficient4(self, Coefficient4: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionBlendEffect(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionFilterEffect
    _iid_ = Guid('{33ecdc0a-578a-4a11-9c14-0cb90517f9c5}')
    @commethod(4)
    def SetMode(self, mode: win32more.Windows.Win32.Graphics.Direct2D.Common.D2D1_BLEND_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionBrightnessEffect(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionFilterEffect
    _iid_ = Guid('{6027496e-cb3a-49ab-934f-d798da4f7da6}')
    @commethod(4)
    def SetWhitePoint(self, whitePoint: POINTER(win32more.Windows.Win32.Graphics.Direct2D.Common.D2D_VECTOR_2F)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetBlackPoint(self, blackPoint: POINTER(win32more.Windows.Win32.Graphics.Direct2D.Common.D2D_VECTOR_2F)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetWhitePointX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetWhitePointX(self, whitePointX: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetWhitePointY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetWhitePointY(self, whitePointY: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetBlackPointX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetBlackPointX(self, blackPointX: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetBlackPointY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetBlackPointY(self, blackPointY: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionClip(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{64ac3703-9d3f-45ec-a109-7cac0e7a13a7}')
class IDCompositionColorMatrixEffect(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionFilterEffect
    _iid_ = Guid('{c1170a22-3ce2-4966-90d4-55408bfc84c4}')
    @commethod(4)
    def SetMatrix(self, matrix: POINTER(win32more.Windows.Win32.Graphics.Direct2D.Common.D2D_MATRIX_5X4_F)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetMatrixElement(self, row: Int32, column: Int32, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetMatrixElement(self, row: Int32, column: Int32, value: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetAlphaMode(self, mode: win32more.Windows.Win32.Graphics.Direct2D.Common.D2D1_COLORMATRIX_ALPHA_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetClampOutput(self, clamp: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionCompositeEffect(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionFilterEffect
    _iid_ = Guid('{576616c0-a231-494d-a38d-00fd5ec4db46}')
    @commethod(4)
    def SetMode(self, mode: win32more.Windows.Win32.Graphics.Direct2D.Common.D2D1_COMPOSITE_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionDelegatedInkTrail(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c2448e9b-547d-4057-8cf5-8144ede1c2da}')
    @commethod(3)
    def AddTrailPoints(self, inkPoints: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.DCompositionInkTrailPoint), inkPointsCount: UInt32, generationId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddTrailPointsWithPrediction(self, inkPoints: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.DCompositionInkTrailPoint), inkPointsCount: UInt32, predictedInkPoints: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.DCompositionInkTrailPoint), predictedInkPointsCount: UInt32, generationId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RemoveTrailPoints(self, generationId: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def StartNewTrail(self, color: POINTER(win32more.Windows.Win32.Graphics.Direct2D.Common.D2D1_COLOR_F)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionDesktopDevice(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionDevice2
    _iid_ = Guid('{5f4633fe-1e08-4cb8-8c75-ce24333f5602}')
    @commethod(24)
    def CreateTargetForHwnd(self, hwnd: win32more.Windows.Win32.Foundation.HWND, topmost: win32more.Windows.Win32.Foundation.BOOL, target: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTarget)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def CreateSurfaceFromHandle(self, handle: win32more.Windows.Win32.Foundation.HANDLE, surface: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def CreateSurfaceFromHwnd(self, hwnd: win32more.Windows.Win32.Foundation.HWND, surface: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionDevice(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c37ea93a-e7aa-450d-b16f-9746cb0407f3}')
    @commethod(3)
    def Commit(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def WaitForCommitCompletion(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetFrameStatistics(self, statistics: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_FRAME_STATISTICS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateTargetForHwnd(self, hwnd: win32more.Windows.Win32.Foundation.HWND, topmost: win32more.Windows.Win32.Foundation.BOOL, target: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTarget)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateVisual(self, visual: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionVisual)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateSurface(self, width: UInt32, height: UInt32, pixelFormat: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, alphaMode: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_ALPHA_MODE, surface: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionSurface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateVirtualSurface(self, initialWidth: UInt32, initialHeight: UInt32, pixelFormat: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, alphaMode: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_ALPHA_MODE, virtualSurface: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionVirtualSurface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CreateSurfaceFromHandle(self, handle: win32more.Windows.Win32.Foundation.HANDLE, surface: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateSurfaceFromHwnd(self, hwnd: win32more.Windows.Win32.Foundation.HWND, surface: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def CreateTranslateTransform(self, translateTransform: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTranslateTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateScaleTransform(self, scaleTransform: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionScaleTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateRotateTransform(self, rotateTransform: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionRotateTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def CreateSkewTransform(self, skewTransform: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionSkewTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def CreateMatrixTransform(self, matrixTransform: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionMatrixTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def CreateTransformGroup(self, transforms: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform), elements: UInt32, transformGroup: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def CreateTranslateTransform3D(self, translateTransform3D: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTranslateTransform3D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def CreateScaleTransform3D(self, scaleTransform3D: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionScaleTransform3D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def CreateRotateTransform3D(self, rotateTransform3D: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionRotateTransform3D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def CreateMatrixTransform3D(self, matrixTransform3D: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionMatrixTransform3D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def CreateTransform3DGroup(self, transforms3D: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform3D), elements: UInt32, transform3DGroup: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform3D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def CreateEffectGroup(self, effectGroup: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionEffectGroup)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def CreateRectangleClip(self, clip: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionRectangleClip)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def CreateAnimation(self, animation: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def CheckDeviceState(self, pfValid: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionDevice2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{75f6468d-1b8e-447c-9bc6-75fea80b5b25}')
    @commethod(3)
    def Commit(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def WaitForCommitCompletion(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetFrameStatistics(self, statistics: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_FRAME_STATISTICS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateVisual(self, visual: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionVisual2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateSurfaceFactory(self, renderingDevice: win32more.Windows.Win32.System.Com.IUnknown, surfaceFactory: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionSurfaceFactory)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateSurface(self, width: UInt32, height: UInt32, pixelFormat: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, alphaMode: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_ALPHA_MODE, surface: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionSurface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateVirtualSurface(self, initialWidth: UInt32, initialHeight: UInt32, pixelFormat: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, alphaMode: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_ALPHA_MODE, virtualSurface: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionVirtualSurface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CreateTranslateTransform(self, translateTransform: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTranslateTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateScaleTransform(self, scaleTransform: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionScaleTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def CreateRotateTransform(self, rotateTransform: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionRotateTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateSkewTransform(self, skewTransform: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionSkewTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateMatrixTransform(self, matrixTransform: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionMatrixTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def CreateTransformGroup(self, transforms: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform), elements: UInt32, transformGroup: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def CreateTranslateTransform3D(self, translateTransform3D: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTranslateTransform3D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def CreateScaleTransform3D(self, scaleTransform3D: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionScaleTransform3D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def CreateRotateTransform3D(self, rotateTransform3D: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionRotateTransform3D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def CreateMatrixTransform3D(self, matrixTransform3D: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionMatrixTransform3D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def CreateTransform3DGroup(self, transforms3D: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform3D), elements: UInt32, transform3DGroup: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform3D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def CreateEffectGroup(self, effectGroup: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionEffectGroup)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def CreateRectangleClip(self, clip: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionRectangleClip)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def CreateAnimation(self, animation: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionDevice3(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionDevice2
    _iid_ = Guid('{0987cb06-f916-48bf-8d35-ce7641781bd9}')
    @commethod(24)
    def CreateGaussianBlurEffect(self, gaussianBlurEffect: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionGaussianBlurEffect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def CreateBrightnessEffect(self, brightnessEffect: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionBrightnessEffect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def CreateColorMatrixEffect(self, colorMatrixEffect: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionColorMatrixEffect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def CreateShadowEffect(self, shadowEffect: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionShadowEffect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def CreateHueRotationEffect(self, hueRotationEffect: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionHueRotationEffect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def CreateSaturationEffect(self, saturationEffect: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionSaturationEffect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def CreateTurbulenceEffect(self, turbulenceEffect: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTurbulenceEffect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def CreateLinearTransferEffect(self, linearTransferEffect: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionLinearTransferEffect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def CreateTableTransferEffect(self, tableTransferEffect: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTableTransferEffect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def CreateCompositeEffect(self, compositeEffect: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionCompositeEffect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def CreateBlendEffect(self, blendEffect: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionBlendEffect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def CreateArithmeticCompositeEffect(self, arithmeticCompositeEffect: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionArithmeticCompositeEffect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def CreateAffineTransform2DEffect(self, affineTransform2dEffect: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAffineTransform2DEffect)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionDevice4(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionDevice3
    _iid_ = Guid('{85fc5cca-2da6-494c-86b6-4a775c049b8a}')
    @commethod(37)
    def CheckCompositionTextureSupport(self, renderingDevice: win32more.Windows.Win32.System.Com.IUnknown, supportsCompositionTextures: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def CreateCompositionTexture(self, d3dTexture: win32more.Windows.Win32.System.Com.IUnknown, compositionTexture: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTexture)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionDeviceDebug(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a1a3c64a-224f-4a81-9773-4f03a89d3c6c}')
    @commethod(3)
    def EnableDebugCounters(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DisableDebugCounters(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionEffect(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ec81b08f-bfcb-4e8d-b193-a915587999e8}')
class IDCompositionEffectGroup(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionEffect
    _iid_ = Guid('{a7929a74-e6b2-4bd6-8b95-4040119ca34d}')
    @commethod(3)
    def SetOpacity(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetOpacity(self, opacity: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetTransform3D(self, transform3D: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform3D) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionFilterEffect(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionEffect
    _iid_ = Guid('{30c421d5-8cb2-4e9f-b133-37be270d4ac2}')
    @commethod(3)
    def SetInput(self, index: UInt32, input: win32more.Windows.Win32.System.Com.IUnknown, flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionGaussianBlurEffect(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionFilterEffect
    _iid_ = Guid('{45d4d0b7-1bd4-454e-8894-2bfa68443033}')
    @commethod(4)
    def SetStandardDeviation(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetStandardDeviation(self, amount: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetBorderMode(self, mode: win32more.Windows.Win32.Graphics.Direct2D.Common.D2D1_BORDER_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionHueRotationEffect(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionFilterEffect
    _iid_ = Guid('{6db9f920-0770-4781-b0c6-381912f9d167}')
    @commethod(4)
    def SetAngle(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetAngle(self, amountDegrees: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionInkTrailDevice(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{df0c7cec-cdeb-4d4a-b91c-721bf22f4e6c}')
    @commethod(3)
    def CreateDelegatedInkTrail(self, inkTrail: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionDelegatedInkTrail)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateDelegatedInkTrailForSwapChain(self, swapChain: win32more.Windows.Win32.System.Com.IUnknown, inkTrail: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionDelegatedInkTrail)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionLinearTransferEffect(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionFilterEffect
    _iid_ = Guid('{4305ee5b-c4a0-4c88-9385-67124e017683}')
    @commethod(4)
    def SetRedYIntercept(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetRedYIntercept(self, redYIntercept: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetRedSlope(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetRedSlope(self, redSlope: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetRedDisable(self, redDisable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetGreenYIntercept(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetGreenYIntercept(self, greenYIntercept: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetGreenSlope(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetGreenSlope(self, greenSlope: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetGreenDisable(self, greenDisable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetBlueYIntercept(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetBlueYIntercept(self, blueYIntercept: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def SetBlueSlope(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def SetBlueSlope(self, blueSlope: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetBlueDisable(self, blueDisable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def SetAlphaYIntercept(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetAlphaYIntercept(self, alphaYIntercept: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def SetAlphaSlope(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def SetAlphaSlope(self, alphaSlope: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def SetAlphaDisable(self, alphaDisable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def SetClampOutput(self, clampOutput: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionMatrixTransform(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform
    _iid_ = Guid('{16cdff07-c503-419c-83f2-0965c7af1fa6}')
    @commethod(3)
    def SetMatrix(self, matrix: POINTER(win32more.Windows.Win32.Graphics.Direct2D.Common.D2D_MATRIX_3X2_F)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetMatrixElement(self, row: Int32, column: Int32, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetMatrixElement(self, row: Int32, column: Int32, value: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionMatrixTransform3D(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform3D
    _iid_ = Guid('{4b3363f0-643b-41b7-b6e0-ccf22d34467c}')
    @commethod(3)
    def SetMatrix(self, matrix: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3DMATRIX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetMatrixElement(self, row: Int32, column: Int32, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetMatrixElement(self, row: Int32, column: Int32, value: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionRectangleClip(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionClip
    _iid_ = Guid('{9842ad7d-d9cf-4908-aed7-48b51da5e7c2}')
    @commethod(3)
    def SetLeft(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetLeft(self, left: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetTop(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetTop(self, top: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetRight(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetRight(self, right: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetBottom(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetBottom(self, bottom: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetTopLeftRadiusX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetTopLeftRadiusX(self, radius: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetTopLeftRadiusY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetTopLeftRadiusY(self, radius: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetTopRightRadiusX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def SetTopRightRadiusX(self, radius: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def SetTopRightRadiusY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetTopRightRadiusY(self, radius: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def SetBottomLeftRadiusX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetBottomLeftRadiusX(self, radius: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def SetBottomLeftRadiusY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def SetBottomLeftRadiusY(self, radius: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def SetBottomRightRadiusX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def SetBottomRightRadiusX(self, radius: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def SetBottomRightRadiusY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def SetBottomRightRadiusY(self, radius: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionRotateTransform(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform
    _iid_ = Guid('{641ed83c-ae96-46c5-90dc-32774cc5c6d5}')
    @commethod(3)
    def SetAngle(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetAngle(self, angle: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetCenterX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetCenterX(self, centerX: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetCenterY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetCenterY(self, centerY: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionRotateTransform3D(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform3D
    _iid_ = Guid('{d8f5b23f-d429-4a91-b55a-d2f45fd75b18}')
    @commethod(3)
    def SetAngle(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetAngle(self, angle: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetAxisX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetAxisX(self, axisX: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetAxisY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetAxisY(self, axisY: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetAxisZ(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetAxisZ(self, axisZ: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetCenterX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetCenterX(self, centerX: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetCenterY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetCenterY(self, centerY: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetCenterZ(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def SetCenterZ(self, centerZ: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionSaturationEffect(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionFilterEffect
    _iid_ = Guid('{a08debda-3258-4fa4-9f16-9174d3fe93b1}')
    @commethod(4)
    def SetSaturation(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetSaturation(self, ratio: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionScaleTransform(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform
    _iid_ = Guid('{71fde914-40ef-45ef-bd51-68b037c339f9}')
    @commethod(3)
    def SetScaleX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetScaleX(self, scaleX: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetScaleY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetScaleY(self, scaleY: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetCenterX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetCenterX(self, centerX: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetCenterY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetCenterY(self, centerY: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionScaleTransform3D(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform3D
    _iid_ = Guid('{2a9e9ead-364b-4b15-a7c4-a1997f78b389}')
    @commethod(3)
    def SetScaleX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetScaleX(self, scaleX: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetScaleY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetScaleY(self, scaleY: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetScaleZ(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetScaleZ(self, scaleZ: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetCenterX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetCenterX(self, centerX: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetCenterY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetCenterY(self, centerY: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetCenterZ(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetCenterZ(self, centerZ: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionShadowEffect(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionFilterEffect
    _iid_ = Guid('{4ad18ac0-cfd2-4c2f-bb62-96e54fdb6879}')
    @commethod(4)
    def SetStandardDeviation(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetStandardDeviation(self, amount: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetColor(self, color: POINTER(win32more.Windows.Win32.Graphics.Direct2D.Common.D2D_VECTOR_4F)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetRed(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetRed(self, amount: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetGreen(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetGreen(self, amount: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetBlue(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetBlue(self, amount: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetAlpha(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetAlpha(self, amount: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionSkewTransform(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform
    _iid_ = Guid('{e57aa735-dcdb-4c72-9c61-0591f58889ee}')
    @commethod(3)
    def SetAngleX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetAngleX(self, angleX: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetAngleY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetAngleY(self, angleY: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetCenterX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetCenterX(self, centerX: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetCenterY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetCenterY(self, centerY: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionSurface(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bb8a4953-2c99-4f5a-96f5-4819027fa3ac}')
    @commethod(3)
    def BeginDraw(self, updateRect: POINTER(win32more.Windows.Win32.Foundation.RECT), iid: POINTER(Guid), updateObject: POINTER(VoidPtr), updateOffset: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EndDraw(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SuspendDraw(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def ResumeDraw(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Scroll(self, scrollRect: POINTER(win32more.Windows.Win32.Foundation.RECT), clipRect: POINTER(win32more.Windows.Win32.Foundation.RECT), offsetX: Int32, offsetY: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionSurfaceFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e334bc12-3937-4e02-85eb-fcf4eb30d2c8}')
    @commethod(3)
    def CreateSurface(self, width: UInt32, height: UInt32, pixelFormat: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, alphaMode: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_ALPHA_MODE, surface: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionSurface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateVirtualSurface(self, initialWidth: UInt32, initialHeight: UInt32, pixelFormat: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_FORMAT, alphaMode: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_ALPHA_MODE, virtualSurface: POINTER(win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionVirtualSurface)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionTableTransferEffect(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionFilterEffect
    _iid_ = Guid('{9b7e82e2-69c5-4eb4-a5f5-a7033f5132cd}')
    @commethod(4)
    def SetRedTable(self, tableValues: POINTER(Single), count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetGreenTable(self, tableValues: POINTER(Single), count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetBlueTable(self, tableValues: POINTER(Single), count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetAlphaTable(self, tableValues: POINTER(Single), count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetRedDisable(self, redDisable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetGreenDisable(self, greenDisable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetBlueDisable(self, blueDisable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetAlphaDisable(self, alphaDisable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetClampOutput(self, clampOutput: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetRedTableValue(self, index: UInt32, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetRedTableValue(self, index: UInt32, value: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetGreenTableValue(self, index: UInt32, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def SetGreenTableValue(self, index: UInt32, value: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def SetBlueTableValue(self, index: UInt32, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetBlueTableValue(self, index: UInt32, value: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def SetAlphaTableValue(self, index: UInt32, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetAlphaTableValue(self, index: UInt32, value: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionTarget(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{eacdd04c-117e-4e17-88f4-d1b12b0e3d89}')
    @commethod(3)
    def SetRoot(self, visual: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionVisual) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionTexture(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{929bb1aa-725f-433b-abd7-273075a835f2}')
    @commethod(3)
    def SetSourceRect(self, sourceRect: POINTER(win32more.Windows.Win32.Graphics.Direct2D.Common.D2D_RECT_U)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetColorSpace(self, colorSpace: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_COLOR_SPACE_TYPE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetAlphaMode(self, alphaMode: win32more.Windows.Win32.Graphics.Dxgi.Common.DXGI_ALPHA_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetAvailableFence(self, fenceValue: POINTER(UInt64), iid: POINTER(Guid), availableFence: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionTransform(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform3D
    _iid_ = Guid('{fd55faa7-37e0-4c20-95d2-9be45bc33f55}')
class IDCompositionTransform3D(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionEffect
    _iid_ = Guid('{71185722-246b-41f2-aad1-0443f7f4bfc2}')
class IDCompositionTranslateTransform(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform
    _iid_ = Guid('{06791122-c6f0-417d-8323-269e987f5954}')
    @commethod(3)
    def SetOffsetX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetOffsetX(self, offsetX: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetOffsetY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetOffsetY(self, offsetY: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionTranslateTransform3D(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform3D
    _iid_ = Guid('{91636d4b-9ba1-4532-aaf7-e3344994d788}')
    @commethod(3)
    def SetOffsetX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetOffsetX(self, offsetX: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetOffsetY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetOffsetY(self, offsetY: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetOffsetZ(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetOffsetZ(self, offsetZ: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionTurbulenceEffect(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionFilterEffect
    _iid_ = Guid('{a6a55bda-c09c-49f3-9193-a41922c89715}')
    @commethod(4)
    def SetOffset(self, offset: POINTER(win32more.Windows.Win32.Graphics.Direct2D.Common.D2D_VECTOR_2F)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetBaseFrequency(self, frequency: POINTER(win32more.Windows.Win32.Graphics.Direct2D.Common.D2D_VECTOR_2F)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetSize(self, size: POINTER(win32more.Windows.Win32.Graphics.Direct2D.Common.D2D_VECTOR_2F)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetNumOctaves(self, numOctaves: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetSeed(self, seed: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetNoise(self, noise: win32more.Windows.Win32.Graphics.Direct2D.Common.D2D1_TURBULENCE_NOISE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetStitchable(self, stitchable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionVirtualSurface(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionSurface
    _iid_ = Guid('{ae471c51-5f53-4a24-8d3e-d0c39c30b3f0}')
    @commethod(8)
    def Resize(self, width: UInt32, height: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Trim(self, rectangles: POINTER(win32more.Windows.Win32.Foundation.RECT), count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionVisual(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4d93059d-097b-4651-9a60-f0f25116e2f3}')
    @commethod(3)
    def SetOffsetX(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetOffsetX(self, offsetX: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetOffsetY(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetOffsetY(self, offsetY: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetTransform(self, transform: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetTransform(self, matrix: POINTER(win32more.Windows.Win32.Graphics.Direct2D.Common.D2D_MATRIX_3X2_F)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetTransformParent(self, visual: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionVisual) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetEffect(self, effect: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionEffect) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetBitmapInterpolationMode(self, interpolationMode: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_BITMAP_INTERPOLATION_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetBorderMode(self, borderMode: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_BORDER_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetClip(self, clip: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionClip) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetClip(self, rect: POINTER(win32more.Windows.Win32.Graphics.Direct2D.Common.D2D_RECT_F)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetContent(self, content: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def AddVisual(self, visual: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionVisual, insertAbove: win32more.Windows.Win32.Foundation.BOOL, referenceVisual: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionVisual) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def RemoveVisual(self, visual: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionVisual) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def RemoveAllVisuals(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def SetCompositeMode(self, compositeMode: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_COMPOSITE_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionVisual2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionVisual
    _iid_ = Guid('{e8de1639-4331-4b26-bc5f-6a321d347a85}')
    @commethod(20)
    def SetOpacityMode(self, mode: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_OPACITY_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def SetBackFaceVisibility(self, visibility: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_BACKFACE_VISIBILITY) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionVisual3(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionVisualDebug
    _iid_ = Guid('{2775f462-b6c1-4015-b0be-b3e7d6a4976d}')
    @commethod(26)
    def SetDepthMode(self, mode: win32more.Windows.Win32.Graphics.DirectComposition.DCOMPOSITION_DEPTH_MODE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def SetOffsetZ(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def SetOffsetZ(self, offsetZ: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def SetOpacity(self, animation: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionAnimation) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def SetOpacity(self, opacity: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def SetTransform(self, transform: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionTransform3D) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def SetTransform(self, matrix: POINTER(win32more.Windows.Win32.Graphics.Direct2D.Common.D2D_MATRIX_4X4_F)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def SetVisible(self, visible: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDCompositionVisualDebug(ComPtr):
    extends: win32more.Windows.Win32.Graphics.DirectComposition.IDCompositionVisual2
    _iid_ = Guid('{fed2b808-5eb4-43a0-aea3-35f65280f91b}')
    @commethod(22)
    def EnableHeatMap(self, color: POINTER(win32more.Windows.Win32.Graphics.Direct2D.Common.D2D1_COLOR_F)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def DisableHeatMap(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def EnableRedrawRegions(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def DisableRedrawRegions(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Phone.StartScreen
import win32more.Windows.UI.Notifications
import win32more.Windows.Win32.System.WinRT
class DualSimTile(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Phone.StartScreen.IDualSimTile
    _classid_ = 'Windows.Phone.StartScreen.DualSimTile'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Phone.StartScreen.DualSimTile.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Phone.StartScreen.DualSimTile: ...
    @winrt_mixinmethod
    def put_DisplayName(self: win32more.Windows.Phone.StartScreen.IDualSimTile, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Phone.StartScreen.IDualSimTile) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_IsPinnedToStart(self: win32more.Windows.Phone.StartScreen.IDualSimTile) -> Boolean: ...
    @winrt_mixinmethod
    def CreateAsync(self: win32more.Windows.Phone.StartScreen.IDualSimTile) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def UpdateAsync(self: win32more.Windows.Phone.StartScreen.IDualSimTile) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def DeleteAsync(self: win32more.Windows.Phone.StartScreen.IDualSimTile) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_classmethod
    def GetTileForSim2(cls: win32more.Windows.Phone.StartScreen.IDualSimTileStatics) -> win32more.Windows.Phone.StartScreen.DualSimTile: ...
    @winrt_classmethod
    def UpdateDisplayNameForSim1Async(cls: win32more.Windows.Phone.StartScreen.IDualSimTileStatics, name: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_classmethod
    def CreateTileUpdaterForSim1(cls: win32more.Windows.Phone.StartScreen.IDualSimTileStatics) -> win32more.Windows.UI.Notifications.TileUpdater: ...
    @winrt_classmethod
    def CreateTileUpdaterForSim2(cls: win32more.Windows.Phone.StartScreen.IDualSimTileStatics) -> win32more.Windows.UI.Notifications.TileUpdater: ...
    @winrt_classmethod
    def CreateBadgeUpdaterForSim1(cls: win32more.Windows.Phone.StartScreen.IDualSimTileStatics) -> win32more.Windows.UI.Notifications.BadgeUpdater: ...
    @winrt_classmethod
    def CreateBadgeUpdaterForSim2(cls: win32more.Windows.Phone.StartScreen.IDualSimTileStatics) -> win32more.Windows.UI.Notifications.BadgeUpdater: ...
    @winrt_classmethod
    def CreateToastNotifierForSim1(cls: win32more.Windows.Phone.StartScreen.IDualSimTileStatics) -> win32more.Windows.UI.Notifications.ToastNotifier: ...
    @winrt_classmethod
    def CreateToastNotifierForSim2(cls: win32more.Windows.Phone.StartScreen.IDualSimTileStatics) -> win32more.Windows.UI.Notifications.ToastNotifier: ...
    DisplayName = property(get_DisplayName, put_DisplayName)
    IsPinnedToStart = property(get_IsPinnedToStart, None)
DualSimTileContract: UInt32 = 65536
class IDualSimTile(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.StartScreen.IDualSimTile'
    _iid_ = Guid('{143ab213-d05f-4041-a18c-3e3fcb75b41e}')
    @winrt_commethod(6)
    def put_DisplayName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_IsPinnedToStart(self) -> Boolean: ...
    @winrt_commethod(9)
    def CreateAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_commethod(10)
    def UpdateAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_commethod(11)
    def DeleteAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    DisplayName = property(get_DisplayName, put_DisplayName)
    IsPinnedToStart = property(get_IsPinnedToStart, None)
class IDualSimTileStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.StartScreen.IDualSimTileStatics'
    _iid_ = Guid('{50567c9e-c58f-4dc9-b6e8-fa6777eeeb37}')
    @winrt_commethod(6)
    def GetTileForSim2(self) -> win32more.Windows.Phone.StartScreen.DualSimTile: ...
    @winrt_commethod(7)
    def UpdateDisplayNameForSim1Async(self, name: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_commethod(8)
    def CreateTileUpdaterForSim1(self) -> win32more.Windows.UI.Notifications.TileUpdater: ...
    @winrt_commethod(9)
    def CreateTileUpdaterForSim2(self) -> win32more.Windows.UI.Notifications.TileUpdater: ...
    @winrt_commethod(10)
    def CreateBadgeUpdaterForSim1(self) -> win32more.Windows.UI.Notifications.BadgeUpdater: ...
    @winrt_commethod(11)
    def CreateBadgeUpdaterForSim2(self) -> win32more.Windows.UI.Notifications.BadgeUpdater: ...
    @winrt_commethod(12)
    def CreateToastNotifierForSim1(self) -> win32more.Windows.UI.Notifications.ToastNotifier: ...
    @winrt_commethod(13)
    def CreateToastNotifierForSim2(self) -> win32more.Windows.UI.Notifications.ToastNotifier: ...
class IToastNotificationManagerStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.StartScreen.IToastNotificationManagerStatics3'
    _iid_ = Guid('{2717f54b-50df-4455-8e6e-41e0fc8e13ce}')
    @winrt_commethod(6)
    def CreateToastNotifierForSecondaryTile(self, tileId: WinRT_String) -> win32more.Windows.UI.Notifications.ToastNotifier: ...


make_ready(__name__)
